﻿using FluentValidation.Results;
using Hotline.Share.Dtos.Snapshot;
using Hotline.Snapshot.Interfaces;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Dependency;

namespace Hotline.Application.Snapshot;
public class BiSnapshotApplication : IBiSnapshotApplication, IScopeDependency
{
    public readonly IOrderSnapshotRepository _orderSnapshotRepository;

    public BiSnapshotApplication(IOrderSnapshotRepository orderSnapshotRepository)
    {
        _orderSnapshotRepository = orderSnapshotRepository;
    }

    public async Task<SnapshotStatisticsOutDto> GetSnapshotStatisticsAsync(SnapshotStatisticsInDto dto, CancellationToken token)
    {
        var query = _orderSnapshotRepository.Queryable()
            .Where((order) => order.CreationTime >= dto.StartTime && order.CreationTime <= dto.EndTime)
            .Select((order) => new SnapshotStatisticsOutDto
            {
                WZSLFWNJS = 0, // 未在受理范围内件数,
                SSPZ12345JS =0, // 随手拍转12345件数,
                SLFWNZJS = 0, // 受理范围内总件数,
                SLFWNPGWGYSXSNHFJS = 0, // 受理范围内派给网格员四小时内回复件数,
                SLFWNPGWGYCGSXSHFJS = 0, // 受理范围内派给网格员超过四小时回复件数
                SLFWNPGWGYWHFJS = 0, // 受理范围内派给网格员未回复件数
                SLFWNA12345ZPGGBMJS = 0, //受理范围内按12345直派给各部门件数,
                SLFWNA12345ZPGGQXJS = 0, //受理范围内按12345直派给各区县件数
                ZXYB = 0, // 中心已办
                BMYB = 0, // 部门已办
                SLFWMYD = 0, //受理范围满意度
                MYL = 0, // 满意量
                BMYL = 0, // 不满意量
                SPBTYHBGS = 0, // 审批不同意红包个数
                SPTYHBGS = 0, // 审批同意红包个数
                TSHBSP = 0, //特殊红包审批统计
                SPTYGS = 0, //审批同意个数
                YFJE = 0, // 已发金额
                JSHFFWGJLGS = 0, //局审核发放网格员奖励个数
                SPTYWGYHBGS = 0, //审批同意（网格员）红包个数
                SPBTYWGYHBGS = 0,  //审批不同意（网格员）红包个数
                SMJLZE = 0, // 市民奖励总额
                SMYFFJLZE = 0,  // 市民已发放奖励总额
                SMDFFJLZE = 0,  // 市民待发奖励总额
                YFG = 0, //已发（个）
                WFLXG = 0, // 无法联系（个）
                WJHBG = 0,  // 婉拒红包（个）
                WGYYFJLJE = 0, //网格员应发奖励金额
                WGYYFFJLZE = 0, // 网格员已发放奖励总额
                WGYDFFJLZE = 0, // 网格员待发放奖励总额
                WGYKKZEYF = 0, // 网格员扣款总额（已发）
                WGYKKZEDF = 0, // 网格员扣款总额（待发）
                SLFWNDBMHQJJS = 0, // 受理范围内多部门会签件件数
                SLFWNRXZXGDJS = 0, // 受理范围内热线中心归档件数
                RXZXFQHQJJS = 0, // 热线中心发起会签件件数
                AQYH = 0, // 安全隐患
                YWCAQYHZG = 0, // 已完成安全隐患整改
                SQYQGDJS = 0, // 申请延期工单件数
                SQYQGDCS = 0, // 申请延期工单次数
                CQJ = 0, // 超期件
                ECBLJSTHBM = 0, // 二次办理件数 - 退回部门
                ECBLJSHFBMYCB = 0, // 二次办理件数-回访不满意重办
                ECBLJSTTDYYJBM = 0, // 二次办理件数-特提到原一级部门
                ECBLGDMYL = 0, // 二次办理工单满意率
                ECBLGDMYLTHBM = 0, // 二次办理工单满意率-退回部门
                ECBLGDMYLHFBMYCB = 0, // 二次办理工单满意率-回访不满意重办
                TTDYYJBMJS = 0, // 特提到原一级部门件数
                TTDPDZJS = 0, // 特提到派单组件数
                QTTTJS = 0, // 其他特提件数
            });
        return await query.FirstAsync();
    }

    public ISugarQueryable<SnapshotStatisticsDetailOutDto> GetSnapshotStatisticsDetail(SnapshotStatisticsDetailInDto dto, CancellationToken requestAborted)
    {
        var query = _orderSnapshotRepository.Queryable()
            .Where((order) => order.CreationTime >= dto.StartTime && order.CreationTime <= dto.EndTime)
            .Select((order) => new SnapshotStatisticsDetailOutDto());
        return query;
    }
}
